# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.models.reading_location import ReadingLocation  # noqa: E501
from teralytic.rest import ApiException


class TestReadingLocation(unittest.TestCase):
    """ReadingLocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReadingLocation(self):
        """Test ReadingLocation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = teralytic.models.reading_location.ReadingLocation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
