# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.api.field_api import FieldApi  # noqa: E501
from teralytic.rest import ApiException


class TestFieldApi(unittest.TestCase):
    """FieldApi unit test stubs"""

    def setUp(self):
        self.api = teralytic.api.field_api.FieldApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_field_get(self):
        """Test case for field_get

        List single Field details associated with Field id provided (from set of Fields associated with the account key)  # noqa: E501
        """
        pass

    def test_field_list(self):
        """Test case for field_list

        List all Fields associated with account key  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
