# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.reading import Reading  # noqa: F401,E501


class Probe(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'serial_code': 'str',
        'field_id': 'str',
        'organization_id': 'str',
        'last_reading': 'Reading'
    }

    attribute_map = {
        'id': 'id',
        'serial_code': 'serial_code',
        'field_id': 'field_id',
        'organization_id': 'organization_id',
        'last_reading': 'last_reading'
    }

    def __init__(self, id=None, serial_code=None, field_id=None, organization_id=None, last_reading=None):  # noqa: E501
        """Probe - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._serial_code = None
        self._field_id = None
        self._organization_id = None
        self._last_reading = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if serial_code is not None:
            self.serial_code = serial_code
        if field_id is not None:
            self.field_id = field_id
        if organization_id is not None:
            self.organization_id = organization_id
        if last_reading is not None:
            self.last_reading = last_reading

    @property
    def id(self):
        """Gets the id of this Probe.  # noqa: E501


        :return: The id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Probe.


        :param id: The id of this Probe.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def serial_code(self):
        """Gets the serial_code of this Probe.  # noqa: E501


        :return: The serial_code of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._serial_code

    @serial_code.setter
    def serial_code(self, serial_code):
        """Sets the serial_code of this Probe.


        :param serial_code: The serial_code of this Probe.  # noqa: E501
        :type: str
        """

        self._serial_code = serial_code

    @property
    def field_id(self):
        """Gets the field_id of this Probe.  # noqa: E501


        :return: The field_id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Probe.


        :param field_id: The field_id of this Probe.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def organization_id(self):
        """Gets the organization_id of this Probe.  # noqa: E501


        :return: The organization_id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this Probe.


        :param organization_id: The organization_id of this Probe.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    @property
    def last_reading(self):
        """Gets the last_reading of this Probe.  # noqa: E501


        :return: The last_reading of this Probe.  # noqa: E501
        :rtype: Reading
        """
        return self._last_reading

    @last_reading.setter
    def last_reading(self, last_reading):
        """Sets the last_reading of this Probe.


        :param last_reading: The last_reading of this Probe.  # noqa: E501
        :type: Reading
        """

        self._last_reading = last_reading

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Probe):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
